***************************************************************************************
//
//             MAKE COEFFICIENT FIELD VECTORS:
//             THIS PROGRAM TAKES NOAA CORRELATION/REGRESSION FIELD DATA 
//             AND PUTS IT INTO FORMAT USEFUL FOR OTHER REGS
***************************************************************************************

clear
set more off
set matsize 3000
set memory 500m

capture log close
log using mmcirc04.log, replace        

//                           CORRELATIONS FIRST

***********************************************************************************
**************************   Module for AO correlation field file  **************
***********************************************************************************

/* lat-lon data */
insheet using latlon.csv

/* position markers: row, column, corr coeff (matrix element) */
ge corcoef=0
ge double r=(90-lat)/2.5+1
ge double c=(180+lon)/2.5+1
keep lat lon r c corcoef

/*  Merge corr coeff matrix and lat-lon records  */
/*  Replace insheet with NOAA data file          */
save rcc ,replace
clear
insheet cm1-cm144 using AO.corr.csv 
save cm ,replace
clear
use rcc
merge using cm

/*  position scalars  */
scalar def rs=0
scalar def cs=0

/* make correlation coefficient matrix of NOAA data columns and final vector*/
mkmat cm*, mat(ccm)
mkmat corcoef

/*  extract correlation coef and place in data vector */
forv z = 1/218 {
               scalar def rs=r[`z']
               scalar def cs=c[`z']
             *  scalar list rs cs  
               matrix corcoef[`z',1] = ccm[rs,cs]
             * display lat[`z'] "   " lon[`z'] "   " corcoef[`z',1]
               }

/*  convert corcoef matrix to variable  and drop everything else */
/*  This name must match NOAA matrix origin  */
svmat double corcoef, name(aocv)
keep aocv
save aocv, replace

/*      End of module  */


***********************************************************************************
**************************   Module for NAO correlation field file  **************
***********************************************************************************

/* lat-lon data */
clear
insheet using latlon.csv

/* position markers: row, column, corr coeff (matrix element) */
ge corcoef=0
ge double r=(90-lat)/2.5+1
ge double c=(180+lon)/2.5+1
keep lat lon r c corcoef

/*  Merge corr coeff matrix and lat-lon records  */
/*  Replace insheet with NOAA data file          */
save rcc ,replace
clear
insheet cm1-cm144 using NAO.corr.csv 
save cm ,replace
clear
use rcc
merge using cm

/*  position scalars  */
scalar def rs=0
scalar def cs=0

/* make correlation coefficient matrix of NOAA data columns and final vector*/
mkmat cm*, mat(ccm)
mkmat corcoef

/*  extract correlation coef and place in data vector */
forv z = 1/218 {
               scalar def rs=r[`z']
               scalar def cs=c[`z']
             *   scalar list rs cs  
               matrix corcoef[`z',1] = ccm[rs,cs]
             ** display lat[`z'] "   " lon[`z'] "   " corcoef[`z',1]
               }

/*  convert corcoef matrix to variable  and drop everything else */
/*  This name must match NOAA matrix origin  */
svmat double corcoef, name(naocv)
save naocv, replace

/*      End of module  */



***********************************************************************************
**************************   Module for PDO correlation field file  **************
***********************************************************************************

/* lat-lon data */
clear
insheet using latlon.csv

/* position markers: row, column, corr coeff (matrix element) */
ge corcoef=0
ge double r=(90-lat)/2.5+1
ge double c=(180+lon)/2.5+1
keep lat lon r c corcoef

/*  Merge corr coeff matrix and lat-lon records  */
/*  Replace insheet with NOAA data file          */
save rcc ,replace
clear
insheet cm1-cm144 using PDO.corr.csv 
save cm ,replace
clear
use rcc
merge using cm

/*  position scalars  */
scalar def rs=0
scalar def cs=0

/* make correlation coefficient matrix of NOAA data columns and final vector*/
mkmat cm*, mat(ccm)
mkmat corcoef

/*  extract correlation coef and place in data vector */
forv z = 1/218 {
               scalar def rs=r[`z']
               scalar def cs=c[`z']
             *   scalar list rs cs  
               matrix corcoef[`z',1] = ccm[rs,cs]
             ** display lat[`z'] "   " lon[`z'] "   " corcoef[`z',1]
               }

/*  convert corcoef matrix to variable  and drop everything else */
/*  This name must match NOAA matrix origin  */
svmat double corcoef, name(pdocv)
save pdocv, replace

/*      End of module  */


***********************************************************************************
**************************   Module for SOI correlation field file  **************
***********************************************************************************

/* lat-lon data */
clear
insheet using latlon.csv

/* position markers: row, column, corr coeff (matrix element) */
ge corcoef=0
ge double r=(90-lat)/2.5+1
ge double c=(180+lon)/2.5+1
keep lat lon r c corcoef

/*  Merge corr coeff matrix and lat-lon records  */
/*  Replace insheet with NOAA data file          */
save rcc ,replace
clear
insheet cm1-cm144 using SOI.corr.csv 
save cm ,replace
clear
use rcc
merge using cm

/*  position scalars  */
scalar def rs=0
scalar def cs=0

/* make correlation coefficient matrix of NOAA data columns and final vector*/
mkmat cm*, mat(ccm)
mkmat corcoef

/*  extract correlation coef and place in data vector */
forv z = 1/218 {
               scalar def rs=r[`z']
               scalar def cs=c[`z']
             *   scalar list rs cs  
               matrix corcoef[`z',1] = ccm[rs,cs]
             ** display lat[`z'] "   " lon[`z'] "   " corcoef[`z',1]
               }

/*  convert corcoef matrix to variable  and drop everything else */
/*  This name must match NOAA matrix origin  */
svmat double corcoef, name(soicv)
save soicv, replace

/*      End of module  */


//                           NOW REGRESSIONS



***********************************************************************************
**************************   Module for AO regression field file  **************
***********************************************************************************

/* lat-lon data */
clear
insheet using latlon.csv

/* position markers: row, column, corr coeff (matrix element) */
ge corcoef=0
ge double r=(90-lat)/2.5+1
ge double c=(180+lon)/2.5+1
keep lat lon r c corcoef

/*  Merge corr coeff matrix and lat-lon records  */
/*  Replace insheet with NOAA data file          */
save rcc ,replace
clear
insheet cm1-cm144 using AO.reg.csv 
save cm ,replace
clear
use rcc
merge using cm

/*  position scalars  */
scalar def rs=0
scalar def cs=0

/* make regression coefficient matrix of NOAA data columns and final vector*/
mkmat cm*, mat(ccm)
mkmat corcoef

/*  extract regression coef and place in data vector */
forv z = 1/218 {
               scalar def rs=r[`z']
               scalar def cs=c[`z']
             *   scalar list rs cs  
               matrix corcoef[`z',1] = ccm[rs,cs]
             ** display lat[`z'] "   " lon[`z'] "   " corcoef[`z',1]
               }

/*  convert corcoef matrix to variable  and drop everything else */
/*  This name must match NOAA matrix origin  */
svmat double corcoef, name(aorv)
keep aorv
save aorv, replace

/*      End of module  */


***********************************************************************************
**************************   Module for NAO regression field file  **************
***********************************************************************************

/* lat-lon data */
clear
insheet using latlon.csv

/* position markers: row, column, corr coeff (matrix element) */
ge corcoef=0
ge double r=(90-lat)/2.5+1
ge double c=(180+lon)/2.5+1
keep lat lon r c corcoef

/*  Merge corr coeff matrix and lat-lon records  */
/*  Replace insheet with NOAA data file          */
save rcc ,replace
clear
insheet cm1-cm144 using NAO.reg.csv 
save cm ,replace
clear
use rcc
merge using cm

/*  position scalars  */
scalar def rs=0
scalar def cs=0

/* make regression coefficient matrix of NOAA data columns and final vector*/
mkmat cm*, mat(ccm)
mkmat corcoef

/*  extract regression coef and place in data vector */
forv z = 1/218 {
               scalar def rs=r[`z']
               scalar def cs=c[`z']
             *   scalar list rs cs  
               matrix corcoef[`z',1] = ccm[rs,cs]
             ** display lat[`z'] "   " lon[`z'] "   " corcoef[`z',1]
               }

/*  convert corcoef matrix to variable  and drop everything else */
/*  This name must match NOAA matrix origin  */
svmat double corcoef, name(naorv)
save naorv, replace

/*      End of module  */



***********************************************************************************
**************************   Module for PDO regression field file  **************
***********************************************************************************

/* lat-lon data */
clear
insheet using latlon.csv

/* position markers: row, column, corr coeff (matrix element) */
ge corcoef=0
ge double r=(90-lat)/2.5+1
ge double c=(180+lon)/2.5+1
keep lat lon r c corcoef

/*  Merge corr coeff matrix and lat-lon records  */
/*  Replace insheet with NOAA data file          */
save rcc ,replace
clear
insheet cm1-cm144 using PDO.reg.csv 
save cm ,replace
clear
use rcc
merge using cm

/*  position scalars  */
scalar def rs=0
scalar def cs=0

/* make regression coefficient matrix of NOAA data columns and final vector*/
mkmat cm*, mat(ccm)
mkmat corcoef

/*  extract regression coef and place in data vector */
forv z = 1/218 {
               scalar def rs=r[`z']
               scalar def cs=c[`z']
             *   scalar list rs cs  
               matrix corcoef[`z',1] = ccm[rs,cs]
             * display lat[`z'] "   " lon[`z'] "   " corcoef[`z',1]
               }

/*  convert corcoef matrix to variable  and drop everything else */
/*  This name must match NOAA matrix origin  */
svmat double corcoef, name(pdorv)
save pdorv, replace

/*      End of module  */


***********************************************************************************
**************************   Module for SOI regression field file  **************
***********************************************************************************

/* lat-lon data */
clear
insheet using latlon.csv

/* position markers: row, column, corr coeff (matrix element) */
ge corcoef=0
ge double r=(90-lat)/2.5+1
ge double c=(180+lon)/2.5+1
keep lat lon r c corcoef

/*  Merge corr coeff matrix and lat-lon records  */
/*  Replace insheet with NOAA data file          */
save rcc ,replace
clear
insheet cm1-cm144 using SOI.reg.csv 
save cm ,replace
clear
use rcc
merge using cm

/*  position scalars  */
scalar def rs=0
scalar def cs=0

/* make regression coefficient matrix of NOAA data columns and final vector*/
mkmat cm*, mat(ccm)
mkmat corcoef

/*  extract regression coef and place in data vector */
forv z = 1/218 {
               scalar def rs=r[`z']
               scalar def cs=c[`z']
             *   scalar list rs cs  
               matrix corcoef[`z',1] = ccm[rs,cs]
             * display lat[`z'] "   " lon[`z'] "   " corcoef[`z',1]
               }

/*  convert corcoef matrix to variable  and drop everything else */
/*  This name must match NOAA matrix origin  */
svmat double corcoef, name(soirv)
save soirv, replace

/*      End of module  */

*******************************************************************************
//
//                     Build data set for regressions
//
*******************************************************************************
clear

insheet using table4.csv             // call complete dataset "cdata"
save cdata, replace

use aocv
merge using cdata
    drop _merge
    save cdata, replace
    clear

use naocv
drop _merge
merge using cdata
drop _merge
    save cdata, replace
    clear

use pdocv
drop _merge
merge using cdata
drop _merge
    save cdata, replace
    clear

use soicv
drop _merge
merge using cdata
drop _merge
    save cdata, replace
    clear


use aorv
merge using cdata
drop _merge
    save cdata, replace
    clear

use naorv
drop _merge
merge using cdata
drop _merge
    save cdata, replace
    clear

use pdorv
drop _merge
merge using cdata
drop _merge
    save cdata, replace
    clear

use soirv
drop _merge
merge using cdata
drop _merge
    save cdata, replace
    clear


*****************************************************************************************************
//                            Re-run Regressions
*****************************************************************************************************



*****************************************************************************************************
//                             DATA PRODUCTION STEPS
*****************************************************************************************************


//           Clear data then reads data from cdata
clear
use cdata
drop c


mvdecode _all, mv(-99)                                   // changes missing value code from -99 to '.'

tabulate country, generate(country)                // generates city dummy variables


sum(_all)                                                         // descriptive statistics
* 

*************************************************************************************************************
*************************************************************************************************************
*
*                   ORIGINAL SPECIFICATION: GLS
*
*************************************************************************************************************
*************************************************************************************************************

*                  Station data (TABLE 1 COLUMN 1)
*
regress strend press water cosablat pop scale79 coal80 coalgrow inc79 gdpgrow soviet surfmiss lit79 , robust
display e(ll) 
est store mm04s
test pop scale79 coal80 coalgrow inc79 gdpgrow                       // P(ECON=0)
test surfmiss lit79                                                  // P(SOC=0)
test pop scale79 coal80 coalgrow inc79 gdpgrow surfmiss lit79 soviet //P(ECON=SOC=SOV=0)



*                  Station data + circs-c (TABLE 1 COLUMN 2)
*
regress strend press water cosablat aocv naocv pdocv soicv pop scale79 coal80 coalgrow inc79 gdpgrow soviet surfmiss lit79 , robust
display e(ll) 
est store mm04sc
test pop scale79 coal80 coalgrow inc79 gdpgrow surfmiss lit79 soviet   //P(X=0)
test aocv naocv pdocv soicv                                            // P(Circ=0)


*                  Gridded data (TABLE 1 COLUMN 3)
*             
regress gtrend press water cosablat pop scale79 coal80 coalgrow inc79 gdpgrow soviet gamiss lit79 , robust
display e(ll) 
est store mm04g
test pop scale79 coal80 coalgrow inc79 gdpgrow                       // P(ECON=0)
test gamiss lit79                                                  // P(SOC=0)
test pop scale79 coal80 coalgrow inc79 gdpgrow gamiss lit79 soviet //P(ECON=SOC=SOV=0)



*                  Gridded data + circs-c (TABLE 1 COLUMN 4)
*             
regress gtrend press water cosablat aocv naocv pdocv soicv pop scale79 coal80 coalgrow inc79 gdpgrow soviet gamiss lit79 , robust
display e(ll) 
est store mm04gc

test pop scale79 coal80 coalgrow inc79 gdpgrow gamiss lit79 soviet   // P(X=0)
test aocv naocv pdocv soicv                                          // P(Circ=0)




****************************** MAKE RESULTS TABLE *********************************************

est table mm04s mm04sc mm04g mm04gc , t(%5.2f) b(%7.3f) stfmt(%9.2f) stats(N r2 ll) style(columns)



*************************************************************************************************************
*************************************************************************************************************
*
*                   REVISED SPECIFICATION: GLS+Clustered Errors
*
*************************************************************************************************************
*************************************************************************************************************


*                  Station data (TABLE 1 COLUMN 1)
*
regress strend press water cosablat pop scale79 coal80 coalgrow inc79 gdpgrow soviet surfmiss lit79 , robust cluster(country)
display e(ll) 
est store cmm04s
test pop scale79 coal80 coalgrow inc79 gdpgrow                       // P(ECON=0)
test surfmiss lit79                                                  // P(SOC=0)
test pop scale79 coal80 coalgrow inc79 gdpgrow surfmiss lit79 soviet //P(ECON=SOC=SOV=0)



*                  Station data + circs-c (TABLE 1 COLUMN 2)
*
regress strend press water cosablat aocv naocv pdocv soicv pop scale79 coal80 coalgrow inc79 gdpgrow soviet surfmiss lit79 , robust cluster(country)
display e(ll) 
est store cmm04sc
test pop scale79 coal80 coalgrow inc79 gdpgrow surfmiss lit79 soviet   //P(X=0)
test aocv naocv pdocv soicv                                            // P(Circ=0)


*                  Gridded data (TABLE 1 COLUMN 3)
*             
regress gtrend press water cosablat pop scale79 coal80 coalgrow inc79 gdpgrow soviet gamiss lit79 , robust cluster(country)
display e(ll) 
est store cmm04g
test pop scale79 coal80 coalgrow inc79 gdpgrow                       // P(ECON=0)
test gamiss lit79                                                  // P(SOC=0)
test pop scale79 coal80 coalgrow inc79 gdpgrow gamiss lit79 soviet //P(ECON=SOC=SOV=0)



*                  Gridded data + circs-c (TABLE 1 COLUMN 4)
*             
regress gtrend press water cosablat aocv naocv pdocv soicv pop scale79 coal80 coalgrow inc79 gdpgrow soviet gamiss lit79 , robust cluster(country)
display e(ll) 
est store cmm04gc

test pop scale79 coal80 coalgrow inc79 gdpgrow gamiss lit79 soviet   // P(X=0)
test pop scale79 coal80 coalgrow inc79 gdpgrow                       // P(ECON=0)
test gamiss lit79                                                    // P(SOC=0)
test aocv naocv pdocv soicv                                          // P(Circ=0)





****************************** MAKE RESULTS TABLE *********************************************

est table cmm04s cmm04sc cmm04g cmm04gc , t(%5.2f) b(%7.3f) stfmt(%9.2f) stats(N r2 ll)  style(columns)




exit

