***************************************************************************************
//
//             THIS PROGRAM TAKES NOAA CORRELATION/REGRESSION FIELD DATA 
//             AND AUGMENTS THE MM07 DATA BASE, THEN
//             RE-DOES THE REGRESSIONS IN THAT PAPER
//
//             DATA PRODUCTION: NOTE THAT NOAA COEFFS CAN BE REGRESSION OR CORRELATION
//                              SO BOTH FORMS ARE EXAMINED
***************************************************************************************

clear
set more off
set matsize 3000
set memory 500m

capture log close
log using mmcirc.log, replace        

***********************************************************************************
//                           CORRELATIONS FIRST
***********************************************************************************



***********************************************************************************
**************************   Module for AO correlation field file  **************
***********************************************************************************

/* lat-lon data */
insheet using latlon.csv

/* position markers: row, column, corr coeff (matrix element) */
ge corcoef=0
ge double r=(90-lat)/2.5+1
ge double c=(180+lon)/2.5+1
keep lat lon r c corcoef

/*  Merge corr coeff matrix and lat-lon records  */
/*  Replace insheet with NOAA data file          */
save rcc ,replace
clear
insheet cm1-cm144 using AO.corr.csv 
save cm ,replace
clear
use rcc
merge using cm

/*  position scalars  */
scalar def rs=0
scalar def cs=0

/* make correlation coefficient matrix of NOAA data columns and final vector*/
mkmat cm*, mat(ccm)
mkmat corcoef

/*  extract correlation coef and place in data vector */
forv z = 1/469 {
               scalar def rs=r[`z']
               scalar def cs=c[`z']
             *  scalar list rs cs  
               matrix corcoef[`z',1] = ccm[rs,cs]
             * display lat[`z'] "   " lon[`z'] "   " corcoef[`z',1]
               }

/*  convert corcoef matrix to variable  and drop everything else */
/*  This name must match NOAA matrix origin  */
svmat double corcoef, name(aocv)
rename aocv1 aocv
keep aocv
save aocv, replace

/*      End of module  */


***********************************************************************************
**************************   Module for NAO correlation field file  **************
***********************************************************************************

/* lat-lon data */
clear
insheet using latlon.csv

/* position markers: row, column, corr coeff (matrix element) */
ge corcoef=0
ge double r=(90-lat)/2.5+1
ge double c=(180+lon)/2.5+1
keep lat lon r c corcoef

/*  Merge corr coeff matrix and lat-lon records  */
/*  Replace insheet with NOAA data file          */
save rcc ,replace
clear
insheet cm1-cm144 using NAO.corr.csv 
save cm ,replace
clear
use rcc
merge using cm

/*  position scalars  */
scalar def rs=0
scalar def cs=0

/* make correlation coefficient matrix of NOAA data columns and final vector*/
mkmat cm*, mat(ccm)
mkmat corcoef

/*  extract correlation coef and place in data vector */
forv z = 1/469 {
               scalar def rs=r[`z']
               scalar def cs=c[`z']
             *   scalar list rs cs  
               matrix corcoef[`z',1] = ccm[rs,cs]
             ** display lat[`z'] "   " lon[`z'] "   " corcoef[`z',1]
               }

/*  convert corcoef matrix to variable  and drop everything else */
/*  This name must match NOAA matrix origin  */
svmat double corcoef, name(naocv)
rename naocv1 naocv
save naocv, replace

/*      End of module  */



***********************************************************************************
**************************   Module for PDO correlation field file  **************
***********************************************************************************

/* lat-lon data */
clear
insheet using latlon.csv

/* position markers: row, column, corr coeff (matrix element) */
ge corcoef=0
ge double r=(90-lat)/2.5+1
ge double c=(180+lon)/2.5+1
keep lat lon r c corcoef

/*  Merge corr coeff matrix and lat-lon records  */
/*  Replace insheet with NOAA data file          */
save rcc ,replace
clear
insheet cm1-cm144 using PDO.corr.csv 
save cm ,replace
clear
use rcc
merge using cm

/*  position scalars  */
scalar def rs=0
scalar def cs=0

/* make correlation coefficient matrix of NOAA data columns and final vector*/
mkmat cm*, mat(ccm)
mkmat corcoef

/*  extract correlation coef and place in data vector */
forv z = 1/469 {
               scalar def rs=r[`z']
               scalar def cs=c[`z']
             *   scalar list rs cs  
               matrix corcoef[`z',1] = ccm[rs,cs]
             ** display lat[`z'] "   " lon[`z'] "   " corcoef[`z',1]
               }

/*  convert corcoef matrix to variable  and drop everything else */
/*  This name must match NOAA matrix origin  */
svmat double corcoef, name(pdocv)
rename pdocv1 pdocv
save pdocv, replace

/*      End of module  */


***********************************************************************************
**************************   Module for SOI correlation field file  **************
***********************************************************************************

/* lat-lon data */
clear
insheet using latlon.csv

/* position markers: row, column, corr coeff (matrix element) */
ge corcoef=0
ge double r=(90-lat)/2.5+1
ge double c=(180+lon)/2.5+1
keep lat lon r c corcoef

/*  Merge corr coeff matrix and lat-lon records  */
/*  Replace insheet with NOAA data file          */
save rcc ,replace
clear
insheet cm1-cm144 using SOI.corr.csv 
save cm ,replace
clear
use rcc
merge using cm

/*  position scalars  */
scalar def rs=0
scalar def cs=0

/* make correlation coefficient matrix of NOAA data columns and final vector*/
mkmat cm*, mat(ccm)
mkmat corcoef

/*  extract correlation coef and place in data vector */
forv z = 1/469 {
               scalar def rs=r[`z']
               scalar def cs=c[`z']
             *   scalar list rs cs  
               matrix corcoef[`z',1] = ccm[rs,cs]
             ** display lat[`z'] "   " lon[`z'] "   " corcoef[`z',1]
               }

/*  convert corcoef matrix to variable  and drop everything else */
/*  This name must match NOAA matrix origin  */
svmat double corcoef, name(soicv)
rename soicv1 soicv
save soicv, replace

/*      End of module  */


***********************************************************************************
//                           NOW REGRESSION FORM
***********************************************************************************



***********************************************************************************
**************************   Module for AO regression field file  **************
***********************************************************************************

/* lat-lon data */
clear
insheet using latlon.csv

/* position markers: row, column, corr coeff (matrix element) */
ge corcoef=0
ge double r=(90-lat)/2.5+1
ge double c=(180+lon)/2.5+1
keep lat lon r c corcoef

/*  Merge corr coeff matrix and lat-lon records  */
/*  Replace insheet with NOAA data file          */
save rcc ,replace
clear
insheet cm1-cm144 using AO.reg.csv 
save cm ,replace
clear
use rcc
merge using cm

/*  position scalars  */
scalar def rs=0
scalar def cs=0

/* make regression coefficient matrix of NOAA data columns and final vector*/
mkmat cm*, mat(ccm)
mkmat corcoef

/*  extract regression coef and place in data vector */
forv z = 1/469 {
               scalar def rs=r[`z']
               scalar def cs=c[`z']
             *   scalar list rs cs  
               matrix corcoef[`z',1] = ccm[rs,cs]
             ** display lat[`z'] "   " lon[`z'] "   " corcoef[`z',1]
               }

/*  convert corcoef matrix to variable  and drop everything else */
/*  This name must match NOAA matrix origin  */
svmat double corcoef, name(aorv)
rename aorv1 aorv
keep aorv
save aorv, replace

/*      End of module  */


***********************************************************************************
**************************   Module for NAO regression field file  **************
***********************************************************************************

/* lat-lon data */
clear
insheet using latlon.csv

/* position markers: row, column, corr coeff (matrix element) */
ge corcoef=0
ge double r=(90-lat)/2.5+1
ge double c=(180+lon)/2.5+1
keep lat lon r c corcoef

/*  Merge corr coeff matrix and lat-lon records  */
/*  Replace insheet with NOAA data file          */
save rcc ,replace
clear
insheet cm1-cm144 using NAO.reg.csv 
save cm ,replace
clear
use rcc
merge using cm

/*  position scalars  */
scalar def rs=0
scalar def cs=0

/* make regression coefficient matrix of NOAA data columns and final vector*/
mkmat cm*, mat(ccm)
mkmat corcoef

/*  extract regression coef and place in data vector */
forv z = 1/469 {
               scalar def rs=r[`z']
               scalar def cs=c[`z']
             *   scalar list rs cs  
               matrix corcoef[`z',1] = ccm[rs,cs]
             ** display lat[`z'] "   " lon[`z'] "   " corcoef[`z',1]
               }

/*  convert corcoef matrix to variable  and drop everything else */
/*  This name must match NOAA matrix origin  */
svmat double corcoef, name(naorv)
rename naorv1 naorv
save naorv, replace

/*      End of module  */



***********************************************************************************
**************************   Module for PDO regression field file  **************
***********************************************************************************

/* lat-lon data */
clear
insheet using latlon.csv

/* position markers: row, column, corr coeff (matrix element) */
ge corcoef=0
ge double r=(90-lat)/2.5+1
ge double c=(180+lon)/2.5+1
keep lat lon r c corcoef

/*  Merge corr coeff matrix and lat-lon records  */
/*  Replace insheet with NOAA data file          */
save rcc ,replace
clear
insheet cm1-cm144 using PDO.reg.csv 
save cm ,replace
clear
use rcc
merge using cm

/*  position scalars  */
scalar def rs=0
scalar def cs=0

/* make regression coefficient matrix of NOAA data columns and final vector*/
mkmat cm*, mat(ccm)
mkmat corcoef

/*  extract regression coef and place in data vector */
forv z = 1/469 {
               scalar def rs=r[`z']
               scalar def cs=c[`z']
             *   scalar list rs cs  
               matrix corcoef[`z',1] = ccm[rs,cs]
             * display lat[`z'] "   " lon[`z'] "   " corcoef[`z',1]
               }

/*  convert corcoef matrix to variable  and drop everything else */
/*  This name must match NOAA matrix origin  */
svmat double corcoef, name(pdorv)
rename pdorv1 pdorv
save pdorv, replace

/*      End of module  */


***********************************************************************************
**************************   Module for SOI regression field file  **************
***********************************************************************************

/* lat-lon data */
clear
insheet using latlon.csv

/* position markers: row, column, corr coeff (matrix element) */
ge corcoef=0
ge double r=(90-lat)/2.5+1
ge double c=(180+lon)/2.5+1
keep lat lon r c corcoef

/*  Merge corr coeff matrix and lat-lon records  */
/*  Replace insheet with NOAA data file          */
save rcc ,replace
clear
insheet cm1-cm144 using SOI.reg.csv 
save cm ,replace
clear
use rcc
merge using cm

/*  position scalars  */
scalar def rs=0
scalar def cs=0

/* make regression coefficient matrix of NOAA data columns and final vector*/
mkmat cm*, mat(ccm)
mkmat corcoef

/*  extract regression coef and place in data vector */
forv z = 1/469 {
               scalar def rs=r[`z']
               scalar def cs=c[`z']
             *   scalar list rs cs  
               matrix corcoef[`z',1] = ccm[rs,cs]
             * display lat[`z'] "   " lon[`z'] "   " corcoef[`z',1]
               }

/*  convert corcoef matrix to variable  and drop everything else */
/*  This name must match NOAA matrix origin  */
svmat double corcoef, name(soirv)
rename soirv1 soirv
save soirv, replace

/*      End of module  */

*******************************************************************************
//
//                     Build data set for regressions
//
*******************************************************************************
clear

insheet using Global7902.csv             // call complete dataset "cdata"
save cdata, replace

use aocv
merge using cdata
    drop _merge
    save cdata, replace
    clear

use naocv
drop _merge
merge using cdata
drop _merge
    save cdata, replace
    clear

use pdocv
drop _merge
merge using cdata
drop _merge
    save cdata, replace
    clear

use soicv
drop _merge
merge using cdata
drop _merge
    save cdata, replace
    clear


use aorv
merge using cdata
drop _merge
    save cdata, replace
    clear

use naorv
drop _merge
merge using cdata
drop _merge
    save cdata, replace
    clear

use pdorv
drop _merge
merge using cdata
drop _merge
    save cdata, replace
    clear

use soirv
drop _merge
merge using cdata
drop _merge
    save cdata, replace
    clear


*****************************************************************************************************
//                            Re-run Regressions
*****************************************************************************************************



*****************************************************************************************************
//                             DATA PRODUCTION STEPS
*****************************************************************************************************


//           Clear data then reads data from cdata
clear
use cdata
drop c


//           DROP ANTARCTIC DATA
drop if lat < -67

generate abslat=abs(lat)
* replace abslat = cos(lat*3.1415927/180)  //       results rerun using coslat yields only minor differences
generate coslat = cos(lat*3.1415927/180)
generate press=slp
generate dry = dslp>0

generate us = pse>45
generate nh = lat>0
generate sh = lat<0
generate westhem=(lon < -30)*(lon > -150)
sum(westhem nh)

//              SURFACE PROCESSES: % growth population, income, GDP & Coal use
//              land is in sq km, pop is in millions; scale popden to persons/km2
//              gdp is in trillions; gdpden is in $millions/km2 

generate p79 =  1000000*pop79/land         
generate p99 =  1000000*pop99/land         


generate g79 =  1000000*gdp79/land
generate g99 =  1000000*gdp99/land 
generate g=g79


//            Growth in % terms

generate poscoal80 = coal80>0                                              // dummy for coal use in 1980 >0 to avoid div0 error
generate c = poscoal80*(coal00/(coal80+(1-poscoal80)*.001)) - poscoal80    // % change from 1980 to 2000

sum(c coal00 coal80)                                                       // if coal80 = 0 then c == 0, but for these countries the 
sum(c coal00 coal80) if poscoal==0                                         // change in coal use was very small

generate y = gdp99/gdp79 - 1                                               // % change from 1979 to 1999

generate m = inc99/inc79 - 1                                                // % change from 1979 to 1999

generate p = pop99/pop79 - 1                                                // % change from 1979 to 1999




//             DATA INHOMOGENEITIES: Resources g79 (1979 GDP/area ), educ (literacy + PSE)
generate e = lit+pse                                                        // educ = sum of Lit and PSE
generate ge=g79*e                                                           // instruments for Hausman Test
generate g2=g*g
generate e2=e*e
generate x=missing

//              Remove rows with missing trends
drop if surf>200                   

//              Count cells with lost records 
sum(missing) if missing>12
sum(missing) if missing==0

//             Rich/poor & Growing/Declining dummy variables
generate rich = inc99>6.635
generate grow = (inc99>inc79)                          


*****************************************************************************************************
//                             DESCRIPTIVE STATS
*****************************************************************************************************

sum(aocv naocv pdocv soicv aorv naorv pdorv soirv)
sum(surf trop nh sh press dry dslp water abslat p m y c e g x inc79 inc99 rich grow)             
pwcorr aocv naocv pdocv soicv
pwcorr aorv naorv pdorv soirv


//              Generate country dummy variables using gdp99 (identical within a country) for clustering

quietly tabulate gdp99, generate(gdp99)                   




*****************************************************************************************************
//                            TABLE 2: Comparison with MM07
*****************************************************************************************************


// ORIGINAL MM07 RESULTS
regress surf trop slp dry dslp water abslat  g e x p m y c ,robust cluster(gdp99)
est store MM07

test g e x                                           // Inhomogeneity
generate odds=1/r(p)
display r(p) "   " odds

test p m y c                                       // Surface processes
generate odds1=1/r(p)
display r(p) "   " odds1

test g e x p m y c                              // All 
generate odds2=1/r(p)
display r(p) "   " odds2

drop odds odds1 odds2

// AUGMENTED WITH CIRCULATION INDEXES - CORRELATION
regress surf trop slp dry dslp water abslat aocv naocv pdocv soicv g e x p m y c ,robust cluster(gdp99)
est store MM07circc

test aocv naocv pdocv soicv                          // circ indexes

test g e x                                           // Inhomogeneity
generate odds=1/r(p)
display r(p) "   " odds

test p m y c                                       // Surface processes
generate odds1=1/r(p)
display r(p) "   " odds1

test g e x p m y c                              // All 
generate odds2=1/r(p)
display r(p) "   " odds2

drop odds odds1 odds2


// AUGMENTED WITH CIRCULATION INDEXES - REGRESSION
regress surf trop slp dry dslp water abslat aorv naorv pdorv soirv g e x p m y c ,robust cluster(gdp99)
est store MM07circr

test aorv naorv pdorv soirv                          // circ indexes

test g e x                                           // Inhomogeneity
generate odds=1/r(p)
display r(p) "   " odds

test p m y c                                       // Surface processes
generate odds1=1/r(p)
display r(p) "   " odds1

test g e x p m y c                              // All 
generate odds2=1/r(p)
display r(p) "   " odds2

est table MM07 MM07circc MM07circr, t(%5.2f) b(%7.4f) stfmt(%9.2f) stats(N r2 ll bic)  style(columns)   


*********************************************************************************************
//
//                RESULTS SUGGEST REGRESSION INDEXES MOST FAVOURABLE TO IPCC HYPOTHESIS, 
//			SO USE THESE FOR REMAINING RE-DO's
//
*********************************************************************************************



// G1: GEOGRAPHY ALONE
regress surf trop slp dry dslp water abslat aorv naorv pdorv soirv ,robust cluster(gdp99)
est store G1


// G2: GEOGRAPHY AND POPULATION GROWTH
regress surf trop slp dry dslp water abslat aorv naorv pdorv soirv p ,robust cluster(gdp99)
est store G2


//  G3: GEOGRAPHY AND INHOMOGENEITIES
regress surf trop slp dry dslp water abslat aorv naorv pdorv soirv g e x ,robust cluster(gdp99)
test g e x
est store G3


// G4: GEOGRAPHY AND SURFACE PROCESSES
regress surf trop slp dry dslp water abslat aorv naorv pdorv soirv        p m y c ,robust cluster(gdp99)
test p m y c
est store G4


// G5: EVERYTHING BUT TROP
regress surf        slp dry dslp water abslat aorv naorv pdorv soirv g e x p m y c ,robust cluster(gdp99)
est store G5
test g e x
test p m y c
test g e x p m y c

// 	FACTORIZE y EFFECT
generate mp=m*p
regress surf trop slp dry dslp water abslat aorv naorv pdorv soirv g e x p m mp c ,robust cluster(gdp99)

//   TEST OF GENERALIZED HOMOGENEITY: SURF-TROP DIFF'S SHOULD BE RANDOM IF SURF DATA UNCONTAMINATED
generate diff = surf-trop
regress diff slp dry dslp water abslat aorv naorv pdorv soirv g e x p m y c ,robust cluster(gdp99)
test g e x                                           // Inhomogeneity
test p m y c                                       // Surface processes
test g e x p m y c                              // All 


// SURF: GEOGRAPHY AND ALL INDICATORS (done above already)
qui regress surf trop slp dry dslp water abslat aorv naorv pdorv soirv g e x p m y c ,robust cluster(gdp99)
est store Sglobe
predict surfhat



// Variance Inflation Factors and Multicollinearity 
vif
quietly regress surf trop slp water abslat aorv naorv pdorv soirv g e x p m mp c ,robust cluster(gdp99)
vif

est table Sglobe G1 G2 G3 G4 G5, t(%5.2f) b(%7.4f) stfmt(%9.2f) stats(N r2 ll )  style(columns)   

pwcorr trop slp dry dslp water abslat aorv naorv pdorv soirv g e x p m y c , star(.05)



*****************************************************************************************************
//                             TABLE 3: SPATIAL AUTOCORRELATION MODELS
*****************************************************************************************************


//                GENERATE Row-Standardized MATRIX AND EIGENVALUES FOR REG COMMANDS
spatwmat using Wmatlin.dta  , name(W1) eigenval(E1) standardize
spatwmat using Wmatsqrt.dta , name(W2) eigenval(E2) standardize
spatwmat using Wmatsq.dta   , name(W3) eigenval(E3) standardize




*****************************************************************************************************
//                     INVERSE LINEAR WEIGHTS

qui regress surf trop slp dry dslp water abslat g e x p m y c 
spatdiag, weights(W1)

qui regress surf trop slp dry dslp water abslat g e x p m y c aorv naorv pdorv soirv 
spatdiag, weights(W1)

spatreg surf trop slp dry dslp water abslat g e x p m y c aorv naorv pdorv soirv , weights(W1) eigenval(E1) model(error) robust
est store Sp1glob

test aorv naorv pdorv soirv                          // circ indexes

test g e x                                           // Inhomogeneity
replace odds=1/r(p)
display r(p) "   " odds

test p m y c                                       // Surface processes
replace odds1=1/r(p)
display r(p) "   " odds1

test g e x p m y c                              // All 
replace odds2=1/r(p)
display r(p) "   " odds2


*****************************************************************************************************
//                     INVERSE SQUARE ROOT WEIGHTS

qui regress surf trop slp dry dslp water abslat g e x p m y c 
spatdiag, weights(W2)

qui regress surf trop slp dry dslp water abslat g e x p m y c aorv naorv pdorv soirv 
spatdiag, weights(W2)

spatreg surf trop slp dry dslp water abslat g e x p m y c aorv naorv pdorv soirv , weights(W2) eigenval(E2) model(error) robust
est store Sp2glob

test aorv naorv pdorv soirv                          // circ indexes

test g e x                                           // Inhomogeneity
replace odds=1/r(p)
display r(p) "   " odds

test p m y c                                       // Surface processes
replace odds1=1/r(p)
display r(p) "   " odds1

test g e x p m y c                              // All 
replace odds2=1/r(p)
display r(p) "   " odds2


*****************************************************************************************************
//                     INVERSE SQUARE WEIGHTS

qui regress surf trop slp dry dslp water abslat g e x p m y c 
spatdiag, weights(W3)

qui regress surf trop slp dry dslp water abslat g e x p m y c aorv naorv pdorv soirv 
spatdiag, weights(W3)

//				ALOFT version
	qui regress trop slp dry dslp water abslat g e x p m y c aorv naorv pdorv soirv 
		spatdiag, weights(W3)

	spatreg trop slp dry dslp water abslat g e x p m y c aorv naorv pdorv soirv , weights(W3) eigenval(E3) model(error) robust
		est store Sp3aloft

		//  TEST DATA QUALITY INDICATORS
		test g e x 

		// TEST LAND PROCESS INDICATORS
		test p m y c

		// TEST ALL INDICATORS
		test g e x p m y c

		// TEST x
		regress x slp dry dslp water abslat 

		test slp+dslp=0
		test _cons+dry=0

		// TEST e
		regress e slp dry dslp water abslat 

		test slp+dslp=0
		test _cons+dry=0


spatreg surf trop slp dry dslp water abslat g e x p m y c aorv naorv pdorv soirv , weights(W3) eigenval(E3) model(error) robust
est store Sp3glob

	test aorv naorv pdorv soirv                          // circ indexes

	test g e x                                           // Inhomogeneity
	replace odds=1/r(p)
	display r(p) "   " odds

	test p m y c                                       // Surface processes
	replace odds1=1/r(p)
	display r(p) "   " odds1

	test g e x p m y c                              // All 
	replace odds2=1/r(p)
	display r(p) "   " odds2

******************************************************************************************
* Generate filtered trends for model with spatial AC (W3)
******************************************************************************************

generate clim=_b[_cons]+_b[trop]*trop+_b[slp]*slp+_b[dry]*dry+_b[dslp]*dslp+_b[water]*water+_b[abslat]*abslat+_b[aorv]*aorv+_b[naorv]*naorv+_b[pdorv]*pdorv+_b[soirv]*soirv+_b[g]*.36762+_b[e]*144.2

generate bias=surf-clim
outfile lat lon bias using trend.txt, replace
sum(surf trop clim)

//              weight by relative gridcell size
egen sgcs = sum(coslat)
generate gcs=coslat/sgcs

sum(surf trop clim) [w=gcs]



est table Sp1glob Sp2glob Sp3glob, t(%5.2f) b(%7.4f) stfmt(%9.2f) stats(N r2 ll )  style(columns)   

est drop Sp1glob Sp2glob Sp3glob

*****************************************************************************************************
//              TABLE 5: Compute results if all countries had US Resources and no distortions:
//                g(US)=1E6*(3.519263/9573110)=0.36762, Lit=99 PSE=45.2; coefs on others=0
*****************************************************************************************************

//             Print US stats
sum g e if us 

quietly regress surf trop slp dry dslp water abslat aorv naorv pdorv soirv g e x p m y c ,robust cluster(gdp99)
generate sclim=_b[_cons]+_b[trop]*trop+_b[slp]*slp+_b[dry]*dry+_b[dslp]*dslp+_b[water]*water+_b[abslat]*abslat+_b[aorv]*aorv+_b[naorv]*naorv+_b[pdorv]*pdorv+_b[soirv]*soirv+_b[g]*.36762+_b[e]*144.2

generate sbias=surf-sclim
sum(surf trop sclim)

//              weight by relative gridcell size
sum(surf trop sclim) [w=gcs]



*****************************************************************************************************
//                             Sglobe Bootstrap
 bootstrap "regress surf trop slp dry dslp water abslat aorv naorv pdorv soirv g e x p m y c , robust cluster(gdp99)" _b ,  reps(500) 
*****************************************************************************************************




*****************************************************************************************************
//               SPECIFICATION TESTS
*****************************************************************************************************


*****************************************************************************************************
//                                        Section 4.3:     RESET TEST
generate surf2=surfhat*surfhat
regress surf surf2 trop slp dry dslp water abslat aorv naorv pdorv soirv g e x p m y c ,robust cluster(gdp99)
*****************************************************************************************************



**************************************************************************************
//                                        Section 4.4:    HAUSMAN TEST FOR ENDOGENEITY

// HAUSMAN TEST STEP 1: EFFICIENT ESTIMATOR
quietly regress surf trop slp dry dslp water abslat aorv naorv pdorv soirv g e x p m y c  
est store m1, title(Efficient Model)

// HAUSMAN TEST STEP 2: FORCE CONSISTENCY BY INSTRUMENTING GROWTH VARIABLES, LEAVE OUT TROP TO AVOID ANY TEMP DATA
quietly regress p g g2 e e2 ge x p79 g79 coal00 gdp79 pop79 soviet slp dry dslp water abslat aorv naorv pdorv soirv 
predict phat

quietly regress m g g2 e e2 ge x p79 g79 coal00 gdp79 pop79 soviet slp dry dslp water abslat aorv naorv pdorv soirv 
predict mhat

quietly regress y g g2 e e2 ge x p79 g79 coal00 gdp79 pop79 soviet slp dry dslp water abslat aorv naorv pdorv soirv 
predict yhat

quietly regress c g g2 e e2 ge x p79 g79 coal00 gdp79 pop79 soviet slp dry dslp water abslat aorv naorv pdorv soirv 
predict chat


// HAUSMAN TEST STEP 3: CONSISTENT ESTIMATOR
quietly regress surf trop slp dry dslp water abslat aorv naorv pdorv soirv g e x phat mhat yhat chat  
est store m2, title(Consistent Model)

// HAUSMAN TEST STEP 4: ESTIMATE GENERALIZED V(B-b) MATRIX (SUEST COMMAND) AND COMPARE PRM'S
suest m1 m2 , cluster(gdp99)
test [m1_mean = m2_mean], cons common
test p = phat , accumulate
test m = mhat , accumulate
test y = yhat , accumulate
test c = chat , accumulate
******************************************************************************************


*****************************************************************************************************
//                            Section 4.2:  REMOVING OUTLIERS

//
//          Obtain diagonals of hat matrix X(X'X)^X' (must use OLS)
quietly regress surf trop slp dry dslp water abslat aorv naorv pdorv soirv g e x p m y c 

//          Compute influence cut-off = 2*mean hatdiag value
predict hh, hat
sum(hh)
generate inf = 2*r(mean)
outfile lat lon using outliers.txt if hh>inf , replace

sum(surf trop slp dry dslp water abslat aorv naorv pdorv soirv g e x p m y c) if hh<inf
sum(surf trop slp dry dslp water abslat aorv naorv pdorv soirv g e x p m y c) if hh>inf


//          Redo regression excluding outliers
regress surf trop slp dry dslp water abslat aorv naorv pdorv soirv g e x p m y c if hh<inf 
est store noout
test g e x                                           // Inhomogeneity
test p m y c                                       // Surface processes
test g e x p m y c                              // All 


//         Simulataneous VCOV matric estimation using suest command
suest m1 noout , cluster(gdp99)

//         Compare coeffs
test [m1_mean = noout_mean] , cons
*****************************************************************************************************



*****************************************************************************************************
//                             TABLE 4 Column 2: RICH SAMPLE
*****************************************************************************************************

regress surf trop slp dry dslp water abslat aorv naorv pdorv soirv g e x p m y c  if rich ==1 , robust cluster(gdp99)
est store Rich


test g e x                                           // Inhomogeneity
test p m y c                                       // Surface processes
test g e x p m y c                              // All 





*****************************************************************************************************
//                             TABLE 4 Column 3: POOR SAMPLE
*****************************************************************************************************


regress surf trop slp dry dslp water abslat aorv naorv pdorv soirv g e x p m y c if rich ==0 , robust cluster(gdp99)
est store Poor

test g e x                                           // Inhomogeneity
test p m y c                                       // Surface processes
test g e x p m y c                              // All 


*****************************************************************************************************
//                             TABLE 4 Column 4: GROWING SAMPLE
*****************************************************************************************************


regress surf trop slp dry dslp water abslat aorv naorv pdorv soirv g e x p m y c  if grow==1 , robust cluster(gdp99)
est store Growing


test g e x                                           // Inhomogeneity
test p m y c                                       // Surface processes
test g e x p m y c                              // All 




*****************************************************************************************************
//                             TABLE 4 Column 5:  DECLINING SAMPLE
*****************************************************************************************************

regress  surf trop slp dry dslp water abslat aorv naorv pdorv soirv g e x p m y c   if grow ==0   , robust cluster(gdp99)
est store Declining


test g e x                                           // Inhomogeneity
test p m y c                                       // Surface processes
test g e x p m y c                              // All 








*****************************************************************************************************
//                             TABLE 4 
*****************************************************************************************************

est table Sglobe Rich Poor Growing Declining , t(%5.2f) b(%7.4f) stfmt(%9.2f) stats(N r2 ll )  style(columns)   
	est drop Rich Poor Growing Declining


*****************************************************************************************************
//                             FIGURE 3: Trend Histograms
*****************************************************************************************************

histogram surf , density kdensity saving(surface, replace) ytitle("Surface") xtitle("") yscale(range(0 2)) ylabel(0(.5)2)
histogram trop,  density kdensity saving(msu, replace) ytitle("Troposphere") xtitle("") yscale(range(0 2)) ylabel(0(.5)2)
histogram clim, density kdensity saving(adjsurf, replace) ytitle("Adjusted Surface") xtitle("Trend, C/Decade") yscale(range(0 2)) ylabel(0(.5)2)
gr combine surface.gph msu.gph adjsurf.gph, saving(3trends, replace) col(1) xcommon title("Distributions of Observed Trends")
gr export trendgraph.eps ,replace mag(75)


*****************************************************************************************************
//                 Section 4.5:  PREDICT RANDOM SUBSAMPLE
*****************************************************************************************************

// initialize variables; replaced in loop
generate subsample = uniform() > 0.3
regress surf trop slp dry dslp water abslat aorv naorv pdorv soirv g e x p m y c if subsample==1
generate predrs=_b[_cons]+_b[trop]*trop+_b[slp]*slp+_b[dry]*dry+_b[dslp]*dslp+_b[water]*water+_b[abslat ]*abslat+_b[aorv]*aorv+_b[naorv]*naorv+_b[pdorv]*pdorv+_b[soirv]*soirv+_b[g]*g+_b[e]*e+_b[x]*x+_b[p]*p+_b[m]*m+_b[y]*y+_b[c]*c
regress surf predrs if subsample==0

//       Graph the sample predicted vs actuals 
scatter predrs surf if subsample==0, xscale(range(-1 1)) yscale(range(-1 1)) xsize(4) ysize(4) xline(0) yline(0) || scatter surf surf if subsample==0 , legend(label(2 "45 degrees")) c(l) xscale(range(-1 1)) yscale(range(-1 1)) msize(vtiny) xtitle("Actual") ytitle("Predicted Random Subsample") 
gr export rs.eps, replace mag(75)


//       Start Program which will be looped using "simulate" command
capture program drop predsub 

         program predsub 

version 8

//       Random Subsample: 30% data removed 
replace subsample = uniform() > 0.3

regress surf trop slp dry dslp water abslat aorv naorv pdorv soirv g e x p m y c if subsample==1
replace predrs=_b[_cons]+_b[trop]*trop+_b[slp]*slp+_b[dry]*dry+_b[dslp]*dslp+_b[water]*water+_b[abslat ]*abslat+_b[aorv]*aorv+_b[naorv]*naorv+_b[pdorv]*pdorv+_b[soirv]*soirv+_b[g]*g+_b[e]*e+_b[x]*x+_b[p]*p+_b[m]*m+_b[y]*y+_b[c]*c

//       Regress observed on predicted and see how they fit 45 degree line
regress surf predrs if subsample==0
test (_cons=0) (predrs=1)
         end

simulate "predsub" con45=_b[_cons] slope45=_b[predrs] fit=e(r2) test45=r(p) , reps(500) dots 
summarize 



exit

